@@ -72,7 +72,7 @@
 #endif /* defined(__FreeBSD__) */
 
 /* XXXar don't define NV_UNIX on MacOSX or vxworks or dos or QNX */
-#if (defined(__unix__) || defined(__unix) ) && !defined(macosx) && !defined(vxworks) && !defined(__DJGPP__) && !defined(NV_UNIX) && !defined(__QNX__) && !defined(__QNXNTO__)/* XXX until removed from Makefiles */
+#if (defined(__unix__) || defined(__unix) ) && !defined(nvmacosx) && !defined(vxworks) && !defined(__DJGPP__) && !defined(NV_UNIX) && !defined(__QNX__) && !defined(__QNXNTO__)/* XXX until removed from Makefiles */
 #   define NV_UNIX
 #endif /* defined(__unix__) */
 
@@ -202,14 +202,6 @@
 #define NV_VERIF_FEATURES
 #endif
 
-// Until we make SIM_BUILD vs. NV_VERIF_FEATURES orthogonal in the RM
-// codepaths, a simulation build (previously only arch NV_MODS) also
-// requires NV_VERIF_FEATURES for sims to work properly.
-
-#if defined(SIM_BUILD)
-#define NV_VERIF_FEATURES
-#endif
-
 /*
  * New, safer family of #define's -- these ones use 0 vs. 1 rather than
  * defined/!defined.  This is advantageous because if you make a typo, say:
@@ -337,7 +329,11 @@
 #else
 #define NVCPU_IS_64_BITS 0
 #endif
-
+#if defined(NVCPU_ARM)
+#define NVCPU_IS_PCIE_CACHE_COHERENT 0
+#else
+#define NVCPU_IS_PCIE_CACHE_COHERENT 1
+#endif
 /*****************************************************************************/
 
 #endif /* __cpuopsys_h_ */
