@@ -21,11 +21,8 @@
 
 #include <sys/param.h>
 
-#if __FreeBSD_version >= 1100000
-#error This driver does not support FreeBSD 11.x/-CURRENT!
-#endif
-#if __FreeBSD_version >= 1000000 && __FreeBSD_version < 1000510
-#error This driver requires FreeBSD 10.0 or later!
+#if __FreeBSD_version >= 1000000
+#error This driver does not support FreeBSD 10.x/-CURRENT!
 #endif
 #if __FreeBSD_version >= 900000 && __FreeBSD_version < 900044
 #error This driver requires FreeBSD 9.0 or later!
@@ -65,7 +62,6 @@
 #include <sys/mman.h>
 #include <sys/file.h>
 #include <sys/poll.h>
-#include <sys/rwlock.h>
 
 #include <sys/syscall.h>
 #include <sys/bus.h>
@@ -106,11 +102,8 @@
 
 #if __FreeBSD_version >= 900041
 #include <sys/capability.h>
-#if __FreeBSD_version < 1000053
-#define cap_rights_init(rights, cap) (cap)
-#endif
 #else
-#define fget(td, fd, rights, fp) fget(td, fd, fp)
+#define fget(td, fd, cap, fp) fget(td, fd, fp)
 #endif
 
 #define __NV_ITHREAD() (curthread->td_pflags & TDP_ITHREAD)
@@ -366,27 +359,12 @@ NvS32  nv_free_system_pages  (nv_state_t *, void *);
         (obj) = NULL;                   \
     }
 
-#if __FreeBSD_version < 1000030
-#define VM_OBJECT_WLOCK(object) VM_OBJECT_LOCK(object)
-#define VM_OBJECT_WUNLOCK(object) VM_OBJECT_UNLOCK(object)
-#endif
-
-#if __FreeBSD_version < 1000055
-#define vm_map_find(map, object, offset, addr, length, \
-        max_addr, find_space, prot, max, cow) \
-  vm_map_find(map, object, offset, addr, length, find_space, prot, max, cow)
-#endif
-
-#if __FreeBSD_version < 1000042
-#define kmem_arena kernel_map
-#endif
-
 #if __FreeBSD_version >= 800000
-#define NV_VM_PAGER_ALLOCATE(type, handle, size, prot, off, cred) \
-  vm_pager_allocate(type, handle, size, prot, off, cred)
+#define NV_VM_PAGER_ALLOCATE(tp,hd,sz,pt,of,cr) \
+  vm_pager_allocate(tp, hd, sz, pt, of, cr)
 #else
-#define NV_VM_PAGER_ALLOCATE(type, handle, size, prot, off, cred) \
-  vm_pager_allocate(type, handle, size, prot, off)
+#define NV_VM_PAGER_ALLOCATE(tp,hd,sz,pt,of,cr) \
+  vm_pager_allocate(tp, hd, sz, pt, of)
 #endif
 
 #if __FreeBSD_version >= 800000
@@ -427,6 +405,9 @@ int    nvidia_open_ctl       (nv_state_t *, struct nvidia_filep *);
 int    nvidia_open_dev       (nv_state_t *, struct nvidia_filep *);
 int    nvidia_close_ctl      (nv_state_t *, struct nvidia_filep *);
 int    nvidia_close_dev      (nv_state_t *, struct nvidia_filep *);
-int    nvidia_mmap_dev_single(nv_state_t *, vm_ooffset_t *, vm_size_t, vm_object_t *);
+int    nvidia_mmap_ctl_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t *,
+        vm_size_t, vm_object_t *);
+int    nvidia_mmap_dev_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t *,
+        vm_size_t, vm_object_t *);
 
 #endif /* __NV_FREEBSD_H__ */
