@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2001 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -29,13 +29,12 @@
 #define NV_MAX_DEVICES 32
 
 typedef struct {
-    NvU32    domain;        /* PCI domain number   */
-    NvU8     bus;           /* PCI bus number      */
-    NvU8     slot;          /* PCI slot number     */
-    NvU8     function;      /* PCI function number */
-    NvU16    vendor_id;     /* PCI vendor ID       */
-    NvU16    device_id;     /* PCI device ID       */
-    NvBool   valid;         /* validation flag     */
+    NvU32    domain;        /* PCI domain number */
+    NvU8     bus;           /* PCI bus number    */
+    NvU8     slot;          /* PCI slot number   */
+    NvU16    vendor_id;     /* PCI vendor ID     */
+    NvU16    device_id;     /* PCI device ID     */
+    NvBool   valid;         /* validation flag   */
 } nv_pci_info_t;
 
 /* NOTE: using an ioctl() number > 55 will overflow! */
@@ -344,7 +343,7 @@ typedef struct
 #define NV_FLAG_MAP_REGS_EARLY         0x0008
 #define NV_FLAG_USE_BAR0_CFG           0x0010
 #define NV_FLAG_USES_MSI               0x0020
-// EMPTY SLOT                          0x0040
+#define NV_FLAG_S4_AVAILABLE           0x0040
 #define NV_FLAG_PASSTHRU               0x0080
 #define NV_FLAG_GVI_IN_SUSPEND         0x0100
 #define NV_FLAG_GVI                    0x0200
@@ -352,7 +351,6 @@ typedef struct
 #define NV_FLAG_PERSISTENT_SW_STATE    0x0800
 #define NV_FLAG_IN_RECOVERY            0x1000
 #define NV_FLAG_SKIP_CFG_CHECK         0x2000
-#define NV_FLAG_UNBIND_LOCK            0x4000
 
 #define NV_PM_ACPI_HIBERNATE    0x0001
 #define NV_PM_ACPI_STANDBY      0x0002
@@ -417,8 +415,6 @@ typedef struct
 #define NV_I2C_CMD_SMBUS_WRITE       4
 #define NV_I2C_CMD_SMBUS_QUICK_WRITE 5
 #define NV_I2C_CMD_SMBUS_QUICK_READ  6
-#define NV_I2C_CMD_SMBUS_BLOCK_READ  7
-#define NV_I2C_CMD_SMBUS_BLOCK_WRITE 8
 
 /*
 ** where we hide our nv_state_t * ...
@@ -473,8 +469,12 @@ typedef struct
         }                                                                   \
     }
 
-#define NV_ALIGN_DOWN(v,g) ((v) & ~((g) - 1))
+#ifndef NV_ALIGN_UP
 #define NV_ALIGN_UP(v,g) (((v) + ((g) - 1)) & ~((g) - 1))
+#endif
+#ifndef NV_ALIGN_DOWN
+#define NV_ALIGN_DOWN(v,g) ((v) & ~((g) - 1))
+#endif
 
 /*
  * driver internal interfaces
@@ -509,11 +509,10 @@ typedef struct
 #endif /* !defined(NV_API_CALL) */
 
 
-void*  NV_API_CALL  nv_alloc_kernel_mapping      (nv_state_t *, NvU64, NvU64, void **);
-RM_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, NvBool);
-
-RM_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, NvU64, NvU64, NvU32, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, NvU64, void *);
+void*      NV_API_CALL  nv_alloc_kernel_mapping  (nv_state_t *, void *, NvU64, NvU32, NvU64, void **);
+RM_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
+RM_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
+RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -524,7 +523,9 @@ void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, NvU32 );
 RM_STATUS  NV_API_CALL  nv_alias_pages           (nv_state_t *, NvU32, NvU32, NvU32, NvU64, NvU64 *, void **);
 RM_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, NvU32, NvBool, NvU32, NvBool, NvU64 *, void **);
 RM_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, NvU32, void *);
-RM_STATUS  NV_API_CALL  nv_guest_pfn_list        (nv_state_t *, unsigned int, unsigned int, unsigned int, unsigned int*);
+
+RM_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, void *);
+RM_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *);
 
 NvS32  NV_API_CALL  nv_start_rc_timer            (nv_state_t *);
 NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
@@ -547,8 +548,6 @@ RM_STATUS  NV_API_CALL  nv_acpi_dsm_method       (nv_state_t *, NvU8 *, NvU32, N
 RM_STATUS  NV_API_CALL  nv_acpi_ddc_method       (nv_state_t *, void *, NvU32 *);
 RM_STATUS  NV_API_CALL  nv_acpi_dod_method       (nv_state_t *, NvU32 *, NvU32 *);
 void*      NV_API_CALL  nv_get_smu_state         (void);
-RM_STATUS  NV_API_CALL  nv_lock_user_pages       (nv_state_t *, void *, NvU64, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_unlock_user_pages     (nv_state_t *, NvU64, NvU64 *, void *);
 RM_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
 RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
 
@@ -563,10 +562,6 @@ RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *,
 #endif
 RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 
-#if defined(NVCPU_X86) || defined(NVCPU_X86_64)
-NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
-#endif
-
 /*
  * ---------------------------------------------------------------------------
  *
@@ -582,7 +577,9 @@ BOOL       NV_API_CALL  rm_free_private_state    (nv_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_init_adapter          (nv_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_disable_adapter       (nv_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_shutdown_adapter      (nv_stack_t *, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_validate_mmap_request (nv_stack_t *, nv_state_t *, NvU64, NvU64, NvU32 *);
+RM_STATUS  NV_API_CALL  rm_validate_mmap_request (nv_stack_t *, nv_state_t *, void *, NvU64, NvU64, NvU32 *, void **, NvU64 *);
+RM_STATUS  NV_API_CALL  rm_acquire_api_lock      (nv_stack_t *);
+RM_STATUS  NV_API_CALL  rm_release_api_lock      (nv_stack_t *);
 RM_STATUS  NV_API_CALL  rm_ioctl                 (nv_stack_t *, nv_state_t *, void *, NvU32, void *, NvU32);
 BOOL       NV_API_CALL  rm_isr                   (nv_stack_t *, nv_state_t *, NvU32 *);
 void       NV_API_CALL  rm_isr_bh                (nv_stack_t *, nv_state_t *);
@@ -592,7 +589,6 @@ RM_STATUS  NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, Nv
 RM_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 RM_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nv_stack_t *, nv_state_t *, void *);
-void       NV_API_CALL  rm_unbind_lock           (nv_stack_t *, nv_state_t *);
 
 RM_STATUS  NV_API_CALL  rm_read_registry_dword   (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
 RM_STATUS  NV_API_CALL  rm_write_registry_dword  (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
@@ -650,8 +646,8 @@ RM_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nv_stack_t *, nvgpuChann
 RM_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
 RM_STATUS  NV_API_CALL rm_gpu_ops_query_caps(nv_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuCaps_t);
 RM_STATUS  NV_API_CALL rm_gpu_ops_get_attached_uuids(nv_stack_t *, NvU8 *pUuidList, unsigned *numGpus);
-RM_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_arch(nv_stack_t *, NvU8 *pUuid, unsigned uuidLength, NvU32 *pGpuArch);
 RM_STATUS  NV_API_CALL rm_gpu_ops_get_uvm_priv_region(NvU64 *pPrivRegionStart, NvU64 *pPrivRegionLength);
+RM_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_arch(nv_stack_t *, NvU8 *pUuid, unsigned uuidLength, NvU32 *pGpuArch);
 RM_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nv_stack_t *, nvgpuChannelHandle_t);
 RM_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nv_stack_t *, nvgpuChannelHandle_t, NvBool *);
 RM_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nv_stack_t *, nvgpuChannelHandle_t);
