@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2011 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -786,12 +786,49 @@ NvBool NV_API_CALL os_is_xen_dom0(void)
     return FALSE;
 }
 
-NvBool NV_API_CALL os_is_vgx_hyper(void)
-{
-    return FALSE;
-}
-
 void NV_API_CALL os_bug_check(NvU32 bugCode, const char *bugCodeStr)
 {
 }
 
+RM_STATUS NV_API_CALL os_lock_user_pages(
+    void   *address,
+    NvU64   page_count,
+    void  **page_array
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
+RM_STATUS NV_API_CALL os_unlock_user_pages(
+    NvU64  page_count,
+    void  *page_array
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
+RM_STATUS NV_API_CALL os_match_mmap_offset(
+    void  *pAllocPrivate,
+    NvU64  offset,
+    NvU64 *pPageIndex
+)
+{
+    struct nvidia_alloc *at = pAllocPrivate;
+    NvU64 i;
+
+    for (i = 0; i < (at->size / PAGE_SIZE); i++) {
+        if (at->alloc_type_contiguous) {
+            if (offset == (at->pte_array[0].physical_address + (i * PAGE_SIZE))) {
+                *pPageIndex = i;
+                return RM_OK;
+            }
+        } else {
+            if (offset == at->pte_array[i].physical_address) {
+                *pPageIndex = i;
+                return RM_OK;
+            }
+        }
+    }
+
+    return RM_ERR_OBJECT_NOT_FOUND;
+}
