@@ -90,7 +90,7 @@ int nvidia_attach(device_t dev)
             if (!sc->BAR_objects[i])
                 goto failed;
 
-            VM_OBJECT_WLOCK(sc->BAR_objects[i]);
+            VM_OBJECT_LOCK(sc->BAR_objects[i]);
             switch (i) {
                 case NV_GPU_BAR_INDEX_FB:
                     vm_object_set_memattr(sc->BAR_objects[i],
@@ -102,7 +102,7 @@ int nvidia_attach(device_t dev)
                             VM_MEMATTR_UNCACHEABLE);
                     break;
             }
-            VM_OBJECT_WUNLOCK(sc->BAR_objects[i]);
+            VM_OBJECT_UNLOCK(sc->BAR_objects[i]);
         }
     }
 
@@ -545,9 +545,9 @@ int nvidia_open_dev(
             if (!sc->UD_object)
                 goto failed;
 
-            VM_OBJECT_WLOCK(sc->UD_object);
+            VM_OBJECT_LOCK(sc->UD_object);
             vm_object_set_memattr(sc->UD_object, VM_MEMATTR_UNCACHEABLE);
-            VM_OBJECT_WUNLOCK(sc->UD_object);
+            VM_OBJECT_UNLOCK(sc->UD_object);
         }
 
         nv->flags |= NV_FLAG_OPEN;
@@ -788,42 +788,21 @@ NvS32 NV_API_CALL nv_get_event(
 
 void* NV_API_CALL nv_alloc_kernel_mapping(
     nv_state_t *nv,
-    NvU64       address,
+    void       *pAllocPrivate,
+    NvU64       pageIndex,
+    NvU32       pageOffset,
     NvU64       size,
-    void      **private
+    void      **ppPrivate
 )
 {
-    struct nvidia_alloc *at;
-    struct nvidia_softc *sc = nv->os_state;
-    uint32_t i;
-    vm_offset_t offset, virtual_address;
+    struct nvidia_alloc *at = pAllocPrivate;
+    vm_offset_t virtual_address;
     int status;
 
-    offset = (vm_offset_t)address & PAGE_MASK;
-    address &= ~PAGE_MASK;
-
-    SLIST_FOREACH(at, &sc->alloc_list, list) {
-        for (i = 0; i < (at->size / PAGE_SIZE); i++) {
-            if (!at->alloc_type_contiguous &&
-                    (address == at->pte_array[i].physical_address))
-                goto found;
-            else if (at->alloc_type_contiguous &&
-                     (address == ((i * PAGE_SIZE) +
-                          at->pte_array[0].physical_address)))
-                goto found;
-        }
-    }
-
-    return NULL;
-
-found:
-    if ((size + (i * PAGE_SIZE)) > at->size)
-        return NULL;
-
     if (at->alloc_type_contiguous) {
-        *private = NULL;
+        *ppPrivate = NULL;
         return (void *)(at->pte_array[0].virtual_address +
-                    (i * PAGE_SIZE) + offset);
+                (pageIndex * PAGE_SIZE) + pageOffset);
     }
 
     size = (size + PAGE_MASK) & ~PAGE_MASK;
@@ -831,8 +810,8 @@ found:
     vm_object_reference(at->object);
     virtual_address = vm_map_min(kernel_map);
 
-    status = vm_map_find(kernel_map, at->object, (i * PAGE_SIZE),
-            &virtual_address, size, 0, VMFS_ANY_SPACE,
+    status = vm_map_find(kernel_map, at->object, (pageIndex * PAGE_SIZE),
+            &virtual_address, size, VMFS_ANY_SPACE,
             (VM_PROT_READ | VM_PROT_WRITE),
             (VM_PROT_READ | VM_PROT_WRITE), 0);
     if (status != KERN_SUCCESS) {
@@ -849,23 +828,24 @@ found:
         return NULL;
     }
 
-    *private = (void *)(NvUPtr)size;
-    return (void *)(virtual_address + offset);
+    *ppPrivate = (void *)(NvUPtr)size;
+
+    return (void *)(virtual_address + pageOffset);
 }
 
 RM_STATUS NV_API_CALL nv_free_kernel_mapping(
     nv_state_t *nv,
+    void       *pAllocPrivate,
     void       *address,
-    void       *private,
-    NvBool      guest_mapping
+    void       *pPrivate
 )
 {
     vm_offset_t virtual_address;
     uint32_t size;
 
-    if (private != NULL) {
+    if (pPrivate != NULL) {
         virtual_address = (vm_offset_t)address & ~PAGE_MASK;
-        size = (NvUPtr)private;
+        size = (NvUPtr)pPrivate;
         vm_map_remove(kernel_map, virtual_address,
             (virtual_address + size));
     }
@@ -875,21 +855,30 @@ RM_STATUS NV_API_CALL nv_free_kernel_mapping(
 
 RM_STATUS NV_API_CALL nv_alloc_user_mapping(
     nv_state_t *nv,
-    NvU64       address,
+    void       *pAllocPrivate,
+    NvU64       pageIndex,
+    NvU32       pageOffset,
     NvU64       size,
     NvU32       protect,
-    NvU64      *user_address,
-    void      **private
+    NvU64      *pUserAddress,
+    void      **ppPrivate
 )
 {
-    *user_address = address;
+    struct nvidia_alloc *at = pAllocPrivate;
+
+    if (at->alloc_type_contiguous)
+        *pUserAddress = (at->pte_array[0].physical_address + (pageIndex * PAGE_SIZE) + pageOffset);
+    else
+        *pUserAddress = (at->pte_array[pageIndex].physical_address + pageOffset);
+
     return RM_OK;
 }
 
 RM_STATUS NV_API_CALL nv_free_user_mapping(
     nv_state_t *nv,
-    NvU64       user_address,
-    void       *priv_data
+    void       *pAllocPrivate,
+    NvU64       userAddress,
+    void       *pPrivate
 )
 {
     return RM_OK;
@@ -947,7 +936,7 @@ NvS32 nv_alloc_contig_pages(
         return ENOMEM;
     }
 
-    address = kmem_alloc_contig(kmem_arena, size, flags, 0,
+    address = kmem_alloc_contig(kernel_map, size, flags, 0,
             sc->dma_mask, PAGE_SIZE, 0, attr);
     if (!address) {
         status = ENOMEM;
@@ -977,9 +966,9 @@ NvS32 nv_alloc_contig_pages(
         goto failed;
     }
 
-    VM_OBJECT_WLOCK(at->object);
+    VM_OBJECT_LOCK(at->object);
     vm_object_set_memattr(at->object, attr);
-    VM_OBJECT_WUNLOCK(at->object);
+    VM_OBJECT_UNLOCK(at->object);
 
     *private = at;
     SLIST_INSERT_HEAD(&sc->alloc_list, at, list);
@@ -996,7 +985,8 @@ failed:
         os_flush_cpu_cache();
 
     if (at->pte_array[0].virtual_address != NULL) {
-        kmem_free(kmem_arena, at->pte_array[0].virtual_address, at->size);
+        kmem_free(kernel_map,
+                at->pte_array[0].virtual_address, at->size);
         malloc_type_freed(M_NVIDIA, at->size);
     }
 
@@ -1022,7 +1012,8 @@ NvS32 nv_free_contig_pages(
     if (at->attr != VM_MEMATTR_WRITE_BACK)
         os_flush_cpu_cache();
 
-    kmem_free(kmem_arena, at->pte_array[0].virtual_address, at->size);
+    kmem_free(kernel_map, at->pte_array[0].virtual_address,
+            at->size);
     malloc_type_freed(M_NVIDIA, at->size);
 
     free(at->pte_array, M_NVIDIA);
@@ -1085,7 +1076,7 @@ NvS32 nv_alloc_system_pages(
     }
 
     for (i = 0; i < count; i++) {
-        address = kmem_alloc_contig(kmem_arena, PAGE_SIZE, flags, 0,
+        address = kmem_alloc_contig(kernel_map, PAGE_SIZE, flags, 0,
                 sc->dma_mask, PAGE_SIZE, 0, attr);
         if (!address) {
             status = ENOMEM;
@@ -1118,9 +1109,9 @@ NvS32 nv_alloc_system_pages(
         goto failed;
     }
 
-    VM_OBJECT_WLOCK(at->object);
+    VM_OBJECT_LOCK(at->object);
     vm_object_set_memattr(at->object, attr);
-    VM_OBJECT_WUNLOCK(at->object);
+    VM_OBJECT_UNLOCK(at->object);
 
     *private = at;
     SLIST_INSERT_HEAD(&sc->alloc_list, at, list);
@@ -1139,7 +1130,8 @@ failed:
     for (i = 0; i < count; i++) {
         if (at->pte_array[i].virtual_address == 0)
             break;
-        kmem_free(kmem_arena, at->pte_array[i].virtual_address, PAGE_SIZE);
+        kmem_free(kernel_map,
+                at->pte_array[i].virtual_address, PAGE_SIZE);
         malloc_type_freed(M_NVIDIA, PAGE_SIZE);
     }
 
@@ -1168,7 +1160,8 @@ NvS32 nv_free_system_pages(
         os_flush_cpu_cache();
 
     for (i = 0; i < count; i++) {
-        kmem_free(kmem_arena, at->pte_array[i].virtual_address, PAGE_SIZE);
+        kmem_free(kernel_map,
+                at->pte_array[i].virtual_address, PAGE_SIZE);
         malloc_type_freed(M_NVIDIA, PAGE_SIZE);
     }
 
@@ -1191,17 +1184,6 @@ RM_STATUS NV_API_CALL nv_alias_pages(
     return RM_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL nv_guest_pfn_list(
-    nv_state_t  *nv,
-    unsigned int key,
-    unsigned int pfn_count,
-    unsigned int offset_index,
-    unsigned int *user_pfn_list
-)
-{
-    return RM_ERR_NOT_SUPPORTED;
-}
-
 RM_STATUS NV_API_CALL nv_alloc_pages(
     nv_state_t *nv,
     NvU32       count,
@@ -1282,8 +1264,9 @@ NvU64 NV_API_CALL nv_get_user_phys_address(NvU64 address)
     return pmap_extract(vmspace_pmap(vm), va);
 }
 
-int nvidia_mmap_dev_single(
+int nvidia_mmap_ctl_single(
     nv_state_t *nv,
+    struct nvidia_filep *filep,
     vm_ooffset_t *offset,
     vm_size_t size,
     vm_object_t *object
@@ -1293,13 +1276,50 @@ int nvidia_mmap_dev_single(
     nv_stack_t *sp;
     RM_STATUS rmStatus;
     struct nvidia_softc *sc = nv->os_state;
-    NvU32 i, prot;
+    NvU64 pageIndex;
+    NvU32 prot;
+
+    sp = sc->api_sp;
+
+    rmStatus = rm_acquire_api_lock(sp);
+    if (rmStatus != RM_OK)
+        return EAGAIN;
+
+    rmStatus = rm_validate_mmap_request(sp, nv, filep, *offset,
+            size, &prot, (void **)&at, &pageIndex);
+    if (rmStatus != RM_OK) {
+        rm_release_api_lock(sp);
+        return EINVAL;
+    }
+
+    vm_object_reference(at->object);
+    *object = at->object;
+    *offset = (pageIndex * PAGE_SIZE);
+
+    rm_release_api_lock(sp);
+
+    return 0;
+}
+
+int nvidia_mmap_dev_single(
+    nv_state_t *nv,
+    struct nvidia_filep *filep,
+    vm_ooffset_t *offset,
+    vm_size_t size,
+    vm_object_t *object
+)
+{
+    nv_stack_t *sp;
+    RM_STATUS rmStatus;
+    struct nvidia_softc *sc = nv->os_state;
+    NvU32 prot;
 
     sp = sc->api_sp;
 
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
 
-    rmStatus = rm_validate_mmap_request(sp, nv, *offset, size, &prot);
+    rmStatus = rm_validate_mmap_request(sp, nv, filep, *offset, size,
+            &prot, NULL, NULL);
     if (rmStatus != RM_OK)
         return EINVAL;
 
@@ -1320,30 +1340,7 @@ int nvidia_mmap_dev_single(
         return 0;
     }
 
-    SLIST_FOREACH(at, &sc->alloc_list, list) {
-        for (i = 0; i < (at->size / PAGE_SIZE); i++) {
-            if (!at->alloc_type_contiguous &&
-                    (*offset == at->pte_array[i].physical_address))
-                goto found;
-            else if (at->alloc_type_contiguous &&
-                     (*offset == ((i * PAGE_SIZE) +
-                          at->pte_array[0].physical_address)))
-                goto found;
-        }
-    }
-
     return EINVAL;
-
-found:
-    if ((size + (i * PAGE_SIZE)) > at->size)
-        return EINVAL;
-
-    vm_object_reference(at->object);
-
-    *object = at->object;
-    *offset = (i * PAGE_SIZE);
-
-    return 0;
 }
 
 void nvidia_rc_timer(void *data)
@@ -1450,22 +1447,20 @@ void* NV_API_CALL nv_get_smu_state(void)
     return NULL;
 }
 
-RM_STATUS NV_API_CALL nv_lock_user_pages(
+RM_STATUS NV_API_CALL nv_dma_map_pages(
     nv_state_t *nv,
-    void       *address,
-    NvU64       count,
+    NvU64       page_count,
     NvU64      *pte_array,
-    void      **private
+    void       *page_array
 )
 {
     return RM_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL nv_unlock_user_pages(
+RM_STATUS NV_API_CALL nv_dma_unmap_pages(
     nv_state_t *nv,
-    NvU64       count,
-    NvU64      *pte_array,
-    void       *private
+    NvU64       page_count,
+    NvU64      *pte_array
 )
 {
     return RM_ERR_NOT_SUPPORTED;
