@@ -399,7 +399,9 @@ typedef NvSFXP32                                                   NvSFXP18_14;
 typedef NvSFXP32                                                   NvSFXP20_12;
 typedef NvSFXP32                                                    NvSFXP24_8;
 typedef NvSFXP32                                                    NvSFXP27_5;
+typedef NvSFXP32                                                    NvSFXP28_4;
 typedef NvSFXP32                                                    NvSFXP29_3;
+typedef NvSFXP32                                                    NvSFXP31_1;
 
 typedef NvUFXP16                                                    NvUFXP0_16;
 typedef NvUFXP16                                                    NvUFXP4_12;
@@ -410,6 +412,8 @@ typedef NvUFXP32                                                   NvUFXP10_22;
 typedef NvUFXP32                                                   NvUFXP16_16;
 typedef NvUFXP32                                                   NvUFXP20_12;
 typedef NvUFXP32                                                    NvUFXP24_8;
+typedef NvUFXP32                                                    NvUFXP25_7;
+typedef NvUFXP32                                                    NvUFXP28_4;
 
 typedef NvU64                                                      NvUFXP48_16;
 
