@@ -169,6 +169,8 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_I2C_SPEED_TOO_HIGH       0x00000050
 #define RM_ERR_INVALID_IRQ_LEVEL        0x00000051
 #define RM_ERR_BUSY_RETRY               0x00000052
+#define RM_ERR_RESET_REQUIRED           0x00000053
+
 #define RM_ERR_INVALID_PATH             0x00000060
 #define RM_ERR_HOT_SWITCH               0x00000061
 #define RM_ERR_MISMATCHED_TARGET        0x00000062
@@ -176,7 +178,7 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_NO_VALID_PATH            0x00000064
 #define RM_ERR_CONSTRAINT_VIOLATION     0x00000065
 #define RM_ERR_CYCLE_DETECTED           0x00000066
-#define RM_ERR_RESET_REQUIRED           0x00000067
+#define RM_ERR_MISMATCHED_SLAVE         0x00000067
 #define RM_ERR_NO_MEMORY                0x00000068
 #define RM_ERR_MORE_DATA_AVAILABLE      0x00000069
 #define RM_ERR_MODULE_LOAD_FAILED       0x0000006A
@@ -195,5 +197,6 @@ typedef NvU32 RM_STATUS;
 #define RM_WARN_HOT_SWITCH                  0x00000161
 #define RM_WARN_MISMATCHED_TARGET           0x00000162
 #define RM_WARN_OUT_OF_RANGE                0x00000163
+#define RM_WARN_MISMATCHED_SLAVE            0x00000167
 
 #endif /* _RMRETVAL_H_ */
